@@ -41,8 +41,8 @@ of which processes are most active right now.
 import operator
 import platform
 import logging
-import six
 import sys
+import io
 import os
 
 from . import px_pager
@@ -51,11 +51,7 @@ from . import px_process
 from . import px_terminal
 from . import px_processinfo
 
-import sys
-
-if sys.version_info.major >= 3:
-    # For mypy PEP-484 static typing validation
-    from typing import Optional, List  # NOQA
+from typing import Optional, List
 
 
 ERROR_REPORTING_HEADER = """
@@ -67,8 +63,7 @@ Problems detected, please send this text to one of:
 """
 
 
-def install(argv):
-    # type: (List[str]) -> None
+def install(argv: List[str]) -> None:
     """Find full path to self"""
     if not argv:
         sys.stderr.write("ERROR: Can't find myself, can't install\n")
@@ -92,23 +87,20 @@ def main():
         argv.remove("--debug")
         loglevel = logging.DEBUG
 
-    stringIO = six.StringIO()
+    stringIO = io.StringIO()
     configureLogging(loglevel, stringIO)
 
     try:
         _main(argv)
-    except Exception:
+    except Exception:  # pylint: disable=broad-except
         LOG = logging.getLogger(__name__)
         LOG.exception("Uncaught Exception")
 
     handleLogMessages(stringIO.getvalue())
 
 
-def configureLogging(loglevel, stringIO):
-    # type: (int, six.StringIO) -> None
-
-    # This method inspired by: https://stackoverflow.com/a/9534960/473672
-
+# This method inspired by: https://stackoverflow.com/a/9534960/473672
+def configureLogging(loglevel: int, stringIO: io.StringIO) -> None:
     rootLogger = logging.getLogger()
     rootLogger.setLevel(loglevel)
 
@@ -127,15 +119,21 @@ def configureLogging(loglevel, stringIO):
     rootLogger.addHandler(handler)
 
 
-def handleLogMessages(messages):
-    # type: (Optional[str]) -> None
+def handleLogMessages(messages: Optional[str]) -> None:
     if not messages:
         return
 
     sys.stderr.write(ERROR_REPORTING_HEADER)
     sys.stderr.write("\n")
 
-    from . import version
+    # If this fails, run "tox.sh" once and the "version.py" file will be created
+    # for you.
+    #
+    # NOTE: If we "import version" at the top of this file, we will depend on it
+    # even if we don't use it. And this will make test avoidance fail to avoid
+    # px.py tests every time you make a new commit (because committing recreates
+    # version.py).
+    from . import version  # pylint: disable=import-outside-toplevel
 
     sys.stderr.write("px version: " + version.VERSION + "\n")
 
@@ -149,8 +147,7 @@ def handleLogMessages(messages):
     sys.exit(1)
 
 
-def _main(argv):
-    # type: (List[str]) -> None
+def _main(argv: List[str]) -> None:
 
     if "--install" in argv:
         install(argv)
@@ -166,16 +163,16 @@ def _main(argv):
         # NOTE: If we "import version" at the top of this file, we will depend on it even if
         # we don't use it. And this will make test avoidance fail to avoid px.py tests every
         # time you make a new commit (because committing recreates version.py).
-        from . import version
+        from . import version  # pylint: disable=import-outside-toplevel
 
         print(version.VERSION)
         return
 
-    with_pager = None  # type: Optional[bool]
-    with_color = None  # type: Optional[bool]
+    with_pager: Optional[bool] = None
+    with_color: Optional[bool] = None
     with_username = True
-    top = False  # type: bool
-    sort_cpupercent = False  # type: bool
+    top: bool = False
+    sort_cpupercent: bool = False
 
     while "--no-pager" in argv:
         with_pager = False
@@ -217,7 +214,7 @@ def _main(argv):
 
     if top:
         # Pulling px_top in on demand like this improves test result caching
-        from . import px_top
+        from . import px_top  # pylint: disable=import-outside-toplevel
 
         px_top.top(search=search)
         return
@@ -232,7 +229,7 @@ def _main(argv):
         processes = px_process.get_all()
         process = px_processinfo.find_process_by_pid(pid, processes)
         if not process:
-            exit("No such PID: {}\n".format(pid))
+            sys.exit(f"No such PID: {pid}")
 
         px_pager.page_process_info(process, processes)
         return
@@ -242,9 +239,9 @@ def _main(argv):
 
     procs = list(filter(lambda p: p.match(search), px_process.get_all()))
 
-    columns = None  # type: Optional[int]
+    columns: Optional[int] = None
     try:
-        rows, columns = px_terminal.get_window_size()
+        _, columns = px_terminal.get_window_size()
     except px_terminal.TerminalError:
         columns = None
 
