@@ -1,27 +1,23 @@
 """Extract information from command lines"""
 
 import re
-import sys
 import os.path
 
-if sys.version_info.major >= 3:
-    # For mypy PEP-484 static typing validation
-    from six import text_type  # NOQA
-    from typing import List  # NOQA
+from typing import List
+from typing import Optional
 
 
 # Match "[kworker/0:0H]", no grouping
-LINUX_KERNEL_PROC = re.compile(u"^\\[[^/ ]+/?[^/ ]+\\]$")
+LINUX_KERNEL_PROC = re.compile("^\\[[^/ ]+/?[^/ ]+\\]$")
 
 # Match "(python2.7)", no grouping
-OSX_PARENTHESIZED_PROC = re.compile(u"^\\([^()]+\\)$")
+OSX_PARENTHESIZED_PROC = re.compile("^\\([^()]+\\)$")
 
 # Name of the Perl interpreter
-PERL_BIN = re.compile(u"^perl[.0-9]*$")
+PERL_BIN = re.compile("^perl[.0-9]*$")
 
 
-def to_array(commandline):
-    # type: (text_type) -> List[text_type]
+def to_array(commandline: str) -> List[str]:
     """Splits a command line string into components"""
     base_split = commandline.split(" ")
     if len(base_split) == 1:
@@ -40,8 +36,7 @@ def to_array(commandline):
     return merged_split
 
 
-def is_human_friendly(command):
-    # type: (text_type) -> bool
+def is_human_friendly(command: str) -> bool:
     """
     AKA "Does this command contain any capital letters?"
     """
@@ -51,8 +46,7 @@ def is_human_friendly(command):
     return False
 
 
-def get_app_name_prefix(commandline):
-    # type: (text_type) -> text_type
+def get_app_name_prefix(commandline: str) -> str:
     """
     On macOS, get which app this command is part of.
     """
@@ -74,8 +68,15 @@ def get_app_name_prefix(commandline):
     return ""
 
 
-def get_command(commandline):
-    # type: (text_type) -> text_type
+def try_clarify_electron(commandline: str) -> Optional[str]:
+    for path_component in to_array(commandline)[0].split("/"):
+        if path_component.endswith(".app"):
+            return path_component[:-4]
+
+    return None
+
+
+def get_command(commandline: str) -> str:
     """
     Extracts the command from the command line.
 
@@ -96,6 +97,11 @@ def get_command(commandline):
     if command.startswith("python") or command == "Python":
         return get_python_command(commandline)
 
+    if command == "Electron":
+        clarified = try_clarify_electron(commandline)
+        if clarified:
+            return clarified
+
     if command == "java":
         return get_java_command(commandline)
 
@@ -108,6 +114,11 @@ def get_command(commandline):
                 "-d",
                 "--debug",
                 "--disable",
+                #
+                # Quickfix for #74, better implementations welcome!
+                # https://github.com/walles/px/issues/74
+                "-Eascii-8bit:ascii-8bit",
+                #
                 "-l",
                 "-n",
                 "-p",
@@ -119,6 +130,7 @@ def get_command(commandline):
                 "-W0",
                 "-W1",
                 "-W2",
+                "--",
             ],
         )
 
@@ -156,8 +168,7 @@ def get_command(commandline):
     return app_name_prefix + command
 
 
-def get_python_command(commandline):
-    # type: (text_type) -> text_type
+def get_python_command(commandline: str) -> str:
     array = to_array(commandline)
     array = list(filter(lambda s: s, array))
 
@@ -199,8 +210,7 @@ def get_python_command(commandline):
     return python
 
 
-def get_sudo_command(commandline):
-    # type: (text_type) -> text_type
+def get_sudo_command(commandline: str) -> str:
     without_sudo = commandline[5:].strip()
     if not without_sudo:
         return "sudo"
@@ -212,8 +222,7 @@ def get_sudo_command(commandline):
     return "sudo " + get_command(without_sudo)
 
 
-def prettify_fully_qualified_java_class(class_name):
-    # type: (text_type) -> text_type
+def prettify_fully_qualified_java_class(class_name: str) -> str:
     split = class_name.split(".")
     if len(split) == 1:
         return split[-1]
@@ -225,8 +234,7 @@ def prettify_fully_qualified_java_class(class_name):
     return split[-1]
 
 
-def get_java_command(commandline):
-    # type: (text_type) -> text_type
+def get_java_command(commandline: str) -> str:
     array = to_array(commandline)
     java = os.path.basename(array[0])
     if len(array) == 1:
@@ -251,7 +259,7 @@ def get_java_command(commandline):
                 # to just returning the command name
                 return java
             return os.path.basename(component)
-        elif state == "scanning":
+        if state == "scanning":
             if component.startswith("-X"):
                 continue
             if component.startswith("-D"):
@@ -293,7 +301,7 @@ def get_java_command(commandline):
                 continue
             if component == "-noverify":
                 continue
-            if component == "-cp" or component == "-classpath":
+            if component in ("-cp", "-classpath"):
                 state = "skip next"
                 continue
             if component == "-jar":
@@ -303,19 +311,20 @@ def get_java_command(commandline):
                 # Unsupported switch, give up
                 return java
             return prettify_fully_qualified_java_class(component)
-        else:
-            raise ValueError(
-                "Unhandled state <{}> at <{}> for: {}".format(state, component, array)
-            )
+
+        raise ValueError(f"Unhandled state <{state}> at <{component}> for: {array}")
 
     # We got to the end without being able to come up with a better name, give up
     return java
 
 
-def get_generic_script_command(commandline, ignore_switches=[]):
-    # type: (text_type, List[text_type]) -> text_type
+def get_generic_script_command(
+    commandline: str, ignore_switches: Optional[List[str]] = None
+) -> str:
     array = to_array(commandline)
 
+    if ignore_switches is None:
+        ignore_switches = []
     while len(array) > 1 and array[1].split("=")[0] in ignore_switches:
         del array[1]
 
