@@ -6,11 +6,9 @@ import subprocess
 
 from . import px_processinfo
 
-if False:
-    # For mypy PEP-484 static typing validation
-    from . import px_process  # NOQA
-    from typing import List  # NOQA
-    from typing import Optional  # NOQA
+from . import px_process
+from typing import List
+from typing import Optional
 
 LOG = logging.getLogger(__name__)
 
@@ -38,7 +36,7 @@ def _pump_info_to_fd(with_fileno, process, processes):
             LOG.warning(
                 "Unexpected OSError pumping process info into pager", exc_info=True
             )
-    except Exception:
+    except Exception:  # pylint: disable=broad-except
         # Logging exceptions on warning level will make them visible to somebody
         # who changes the LOGLEVEL in px.py, but not to ordinary users.
         #
@@ -50,15 +48,14 @@ def _pump_info_to_fd(with_fileno, process, processes):
 
 
 # From: https://stackoverflow.com/a/377028/473672
-def which(program):
-    # type: (Optional[str]) -> Optional[str]
+def which(program: Optional[str]) -> Optional[str]:
     if not program:
         return None
 
     def is_exe(fpath):
         return os.path.isfile(fpath) and os.access(fpath, os.X_OK)
 
-    fpath, fname = os.path.split(program)
+    fpath, _ = os.path.split(program)
     if fpath:
         if is_exe(program):
             return program
@@ -71,8 +68,7 @@ def which(program):
     return None
 
 
-def to_command_line(spec):
-    # type: (Optional[str]) -> Optional[List[str]]
+def to_command_line(spec: Optional[str]) -> Optional[List[str]]:
     if not spec:
         return None
 
@@ -118,8 +114,9 @@ def launch_pager():
     return subprocess.Popen(pager_cmd, stdin=subprocess.PIPE, env=env)
 
 
-def page_process_info(process, processes):
-    # type: (px_process.PxProcess, List[px_process.PxProcess]) -> None
+def page_process_info(
+    process: px_process.PxProcess, processes: List[px_process.PxProcess]
+) -> None:
 
     pager = launch_pager()
     pager_stdin = pager.stdin
@@ -134,7 +131,7 @@ def page_process_info(process, processes):
 
     pagerExitcode = pager.wait()
     if pagerExitcode != 0:
-        LOG.warn("Pager exited with code %d", pagerExitcode)
+        LOG.warning("Pager exited with code %d", pagerExitcode)
 
     # FIXME: Maybe join info_thread here as well to ensure we aren't still pumping before returning?
     # This could possibly prevent https://github.com/walles/px/issues/67
