@@ -5,7 +5,6 @@ import operator
 import os
 import re
 import pwd
-import six
 import errno
 import subprocess
 import dateutil.tz
@@ -14,17 +13,11 @@ from . import px_commandline
 from . import px_exec_util
 
 
-import sys
-
-if sys.version_info.major >= 3:
-    # For mypy PEP-484 static typing validation
-    from typing import Dict  # NOQA
-    from typing import MutableSet  # NOQA
-    from typing import Text  # NOQA
-    from typing import Optional  # NOQA
-    from typing import List  # NOQA
-    from typing import Iterable  # NOQA
-    from six import text_type  # NOQA
+from typing import Dict
+from typing import MutableSet
+from typing import Optional
+from typing import List
+from typing import Iterable
 
 
 LOG = logging.getLogger(__name__)
@@ -32,7 +25,7 @@ LOG = logging.getLogger(__name__)
 
 # Match + group: " 7708 1 Mon Mar  7 09:33:11 2016  netbios 0.1 0:00.08  0.0 /usr/sbin/netbiosd hj"
 PS_LINE = re.compile(
-    " *([0-9]+) +([0-9]+) +([A-Za-z0-9: ]+) +([^ ]+) +([0-9.]+) +([-0-9.:]+) +([0-9.]+) +(.*)"
+    " *([0-9]+) +([0-9]+) +([0-9]+) +([A-Za-z0-9: ]+) +([^ ]+) +([0-9.]+) +([-0-9.:]+) +([0-9.]+) +(.*)"
 )
 
 # Match + group: "1:02.03"
@@ -48,12 +41,11 @@ CPUTIME_LINUX_DAYS = re.compile("^([0-9]+)-([0-9][0-9]):([0-9][0-9]):([0-9][0-9]
 TIMEZONE = dateutil.tz.tzlocal()
 
 
-uid_to_username_cache = {}  # type: Dict[int, Text]
-get_command_cache = {}  # type: Dict[Text, Text]
+uid_to_username_cache: Dict[int, str] = {}
+get_command_cache: Dict[str, str] = {}
 
 
-def _parse_time(time_s):
-    # type: (Text)->datetime.datetime
+def _parse_time(time_s: str) -> datetime.datetime:
     """
     Parse a local date from ps into a datetime.datetime object.
 
@@ -63,18 +55,18 @@ def _parse_time(time_s):
     """
 
     zero_based_month = [
-        u"Jan",
-        u"Feb",
-        u"Mar",
-        u"Apr",
-        u"May",
-        u"Jun",
-        u"Jul",
-        u"Aug",
-        u"Sep",
-        u"Oct",
-        u"Nov",
-        u"Dec",
+        "Jan",
+        "Feb",
+        "Mar",
+        "Apr",
+        "May",
+        "Jun",
+        "Jul",
+        "Aug",
+        "Sep",
+        "Oct",
+        "Nov",
+        "Dec",
     ].index(time_s[4:7])
 
     day_of_month = int(time_s[8:10])
@@ -88,29 +80,31 @@ def _parse_time(time_s):
     )
 
 
-class PxProcess(object):
+class PxProcess:
+    # pylint: disable=attribute-defined-outside-init
     def __init__(
         self,
-        cmdline,  # type: Text
-        pid,  # type: int
-        start_time_string,  # type: Text
-        username,  # type: Text
-        now,  # type: datetime.datetime
-        ppid,  # type: Optional[int]
-        memory_percent=None,  # type: Optional[float]
-        cpu_percent=None,  # type: Optional[float]
-        cpu_time=None,  # type: Optional[float]
-    ):
-        # type: (...) -> None
-        self.pid = pid  # type: int
-        self.ppid = ppid  # type: Optional[int]
+        cmdline: str,
+        pid: int,
+        rss_kb: int,
+        start_time_string: str,
+        username: str,
+        now: datetime.datetime,
+        ppid: Optional[int],
+        memory_percent: Optional[float] = None,
+        cpu_percent: Optional[float] = None,
+        cpu_time: Optional[float] = None,
+    ) -> None:
+        self.pid: int = pid
+        self.ppid: Optional[int] = ppid
+        self.rss_kb: int = rss_kb
 
-        self.cmdline = cmdline  # type: text_type
-        self.command = self._get_command()  # type: text_type
-        self.lowercase_command = self.command.lower()  # type: text_type
+        self.cmdline: str = cmdline
+        self.command: str = self._get_command()
+        self.lowercase_command: str = self.command.lower()
 
         self.start_time = _parse_time(start_time_string.strip())
-        self.age_seconds = (now - self.start_time).total_seconds()  # type: float
+        self.age_seconds: float = (now - self.start_time).total_seconds()
         if self.age_seconds < -10:
             # See: https://github.com/walles/px/issues/84
             #
@@ -135,25 +129,25 @@ class PxProcess(object):
         if self.age_seconds < 0:
             self.age_seconds = 0
 
-        self.age_s = seconds_to_str(self.age_seconds)  # type: text_type
+        self.age_s: str = seconds_to_str(self.age_seconds)
 
-        self.username = username  # type: text_type
+        self.username: str = username
 
         self.memory_percent = memory_percent
-        self.memory_percent_s = "--"  # type: text_type
+        self.memory_percent_s: str = "--"
         if memory_percent is not None:
-            self.memory_percent_s = "{:.0f}%".format(memory_percent)
+            self.memory_percent_s = f"{memory_percent:.0f}%"
 
         self.cpu_percent = cpu_percent
-        self.cpu_percent_s = "--"  # type: text_type
+        self.cpu_percent_s: str = "--"
         if cpu_percent is not None:
-            self.cpu_percent_s = "{:.0f}%".format(cpu_percent)
+            self.cpu_percent_s = f"{cpu_percent:.0f}%"
 
         # Setting the CPU time like this implicitly recomputes the score
         self.set_cpu_time_seconds(cpu_time)
 
-        self.children = set()  # type: MutableSet[PxProcess]
-        self.parent = None  # type: Optional[PxProcess]
+        self.children: MutableSet[PxProcess] = set()
+        self.parent: Optional[PxProcess] = None
 
     def __repr__(self):
         # I guess this is really what __str__ should be doing, but the point of
@@ -188,9 +182,8 @@ class PxProcess(object):
             / (self.age_seconds + 1.0)
         )
 
-    def set_cpu_time_seconds(self, seconds):
-        # type: (Optional[float]) -> None
-        self.cpu_time_s = "--"  # type: Text
+    def set_cpu_time_seconds(self, seconds: Optional[float]) -> None:
+        self.cpu_time_s: str = "--"
         self.cpu_time_seconds = None
         if seconds is not None:
             self.cpu_time_s = seconds_to_str(seconds)
@@ -261,39 +254,45 @@ class PxProcess(object):
         return True
 
 
-class PxProcessBuilder(object):
+class PxProcessBuilder:
     def __init__(self):
-        self.cmdline = None  # type: Optional[Text]
-        self.pid = None  # type: Optional[int]
-        self.ppid = None  # type: Optional[int]
-        self.start_time_string = None  # type: Optional[Text]
-        self.username = None  # type: Optional[Text]
-        self.cpu_percent = None  # type: Optional[float]
-        self.cpu_time = None  # type: Optional[float]
-        self.memory_percent = None  # type: Optional[float]
+        self.cmdline: Optional[str] = None
+        self.pid: Optional[int] = None
+        self.ppid: Optional[int] = None
+        self.rss_kb: Optional[int] = None
+        self.start_time_string: Optional[str] = None
+        self.username: Optional[str] = None
+        self.cpu_percent: Optional[float] = None
+        self.cpu_time: Optional[float] = None
+        self.memory_percent: Optional[float] = None
 
     def __repr__(self):
-        return "start_time_string=%r pid=%r ppid=%r user=%r cpu%%=%r cputime=%r mem%%=%r cmd=<%r>" % (
-            self.start_time_string,
-            self.pid,
-            self.ppid,
-            self.username,
-            self.cpu_percent,
-            self.cpu_time,
-            self.memory_percent,
-            self.cmdline,
+        # pylint: disable=consider-using-f-string
+        return (
+            "start_time_string=%r pid=%r ppid=%r user=%r cpu%%=%r cputime=%r mem%%=%r cmd=<%r>"
+            % (
+                self.start_time_string,
+                self.pid,
+                self.ppid,
+                self.username,
+                self.cpu_percent,
+                self.cpu_time,
+                self.memory_percent,
+                self.cmdline,
+            )
         )
 
-    def build(self, now):
-        # type: (datetime.datetime) -> PxProcess
+    def build(self, now: datetime.datetime) -> PxProcess:
         assert self.cmdline
         assert self.pid is not None
+        assert self.rss_kb is not None
         assert self.start_time_string
         assert self.username
         return PxProcess(
             cmdline=self.cmdline,
             pid=self.pid,
             ppid=self.ppid,
+            rss_kb=self.rss_kb,
             start_time_string=self.start_time_string,
             username=self.username,
             now=now,
@@ -303,8 +302,7 @@ class PxProcessBuilder(object):
         )
 
 
-def parse_time(timestring):
-    # type: (Text) -> float
+def parse_time(timestring: str) -> float:
     """Convert a CPU time string returned by ps to a number of seconds"""
 
     match = CPUTIME_OSX.match(timestring)
@@ -331,41 +329,39 @@ def parse_time(timestring):
     raise ValueError("Unparsable timestamp: <" + timestring + ">")
 
 
-def uid_to_username(uid):
-    # type: (int)->Text
+def uid_to_username(uid: int) -> str:
     if uid in uid_to_username_cache:
         return uid_to_username_cache[uid]
 
     # Populate cache
     try:
-        uid_to_username_cache[uid] = six.text_type(pwd.getpwuid(uid).pw_name)
+        uid_to_username_cache[uid] = str(pwd.getpwuid(uid).pw_name)
     except KeyError:
-        uid_to_username_cache[uid] = six.text_type(uid)
+        uid_to_username_cache[uid] = str(uid)
 
     return uid_to_username_cache[uid]
 
 
-def ps_line_to_process(ps_line, now):
-    # type: (Text, datetime.datetime) -> PxProcess
+def ps_line_to_process(ps_line: str, now: datetime.datetime) -> PxProcess:
     match = PS_LINE.match(ps_line)
     if not match:
-        raise Exception("Failed to match ps line <%r>" % ps_line)
+        raise Exception(f"Failed to match ps line <{ps_line:!r}>")
 
     process_builder = PxProcessBuilder()
     process_builder.pid = int(match.group(1))
     process_builder.ppid = int(match.group(2))
-    process_builder.start_time_string = match.group(3)
-    process_builder.username = uid_to_username(int(match.group(4)))
-    process_builder.cpu_percent = float(match.group(5))
-    process_builder.cpu_time = parse_time(match.group(6))
-    process_builder.memory_percent = float(match.group(7))
-    process_builder.cmdline = match.group(8)
+    process_builder.rss_kb = int(match.group(3))
+    process_builder.start_time_string = match.group(4)
+    process_builder.username = uid_to_username(int(match.group(5)))
+    process_builder.cpu_percent = float(match.group(6))
+    process_builder.cpu_time = parse_time(match.group(7))
+    process_builder.memory_percent = float(match.group(8))
+    process_builder.cmdline = match.group(9)
 
     return process_builder.build(now)
 
 
-def create_kernel_process(now):
-    # type: (datetime.datetime) -> PxProcess
+def create_kernel_process(now: datetime.datetime) -> PxProcess:
     """
     Fake a process 0, this one isn't returned by ps. More info about PID 0:
     https://en.wikipedia.org/wiki/Process_identifier
@@ -379,17 +375,17 @@ def create_kernel_process(now):
         "%c"
     )
 
-    process_builder.username = u"root"
+    process_builder.rss_kb = 0
+    process_builder.username = "root"
     process_builder.cpu_time = None
     process_builder.memory_percent = None
-    process_builder.cmdline = u"kernel PID 0"
+    process_builder.cmdline = "kernel PID 0"
     process = process_builder.build(now)
 
     return process
 
 
-def resolve_links(processes, now):
-    # type: (Dict[int, PxProcess], datetime.datetime) -> None
+def resolve_links(processes: Dict[int, PxProcess], now: datetime.datetime) -> None:
     """
     On entry, this function assumes that all processes have a "ppid" field
     containing the PID of their parent process.
@@ -416,8 +412,7 @@ def resolve_links(processes, now):
             process.parent.children.add(process)
 
 
-def remove_process_and_descendants(processes, pid):
-    # type: (Dict[int, PxProcess], int) -> None
+def remove_process_and_descendants(processes: Dict[int, PxProcess], pid: int) -> None:
     process = processes[pid]
     if process.parent is not None:
         process.parent.children.remove(process)
@@ -429,8 +424,7 @@ def remove_process_and_descendants(processes, pid):
             toexclude.append(child)
 
 
-def get_all():
-    # type: () -> List[PxProcess]
+def get_all() -> List[PxProcess]:
     processes = {}
 
     # NOTE: Both the full path to ps and "close_fds = False" are important
@@ -449,28 +443,28 @@ def get_all():
         "/bin/ps",
         "-ax",
         "-o",
-        "pid=,ppid=,lstart=,uid=,pcpu=,time=,%mem=,command=",
+        "pid=,ppid=,rss=,lstart=,uid=,pcpu=,time=,%mem=,command=",
     ]
 
-    with open(os.devnull, "w") as DEVNULL:
-        ps = subprocess.Popen(
+    with open(os.devnull, "w", encoding="utf-8") as DEVNULL:
+        with subprocess.Popen(
             command,
             stdin=DEVNULL,
             stdout=subprocess.PIPE,
             stderr=DEVNULL,
             close_fds=close_fds,
             env=px_exec_util.ENV,
-        )
+        ) as ps:
 
-        stdout = ps.stdout
-        assert stdout
-        now = datetime.datetime.now().replace(tzinfo=TIMEZONE)
-        for ps_line in stdout:
-            process = ps_line_to_process(ps_line.decode("utf-8"), now)
-            processes[process.pid] = process
+            stdout = ps.stdout
+            assert stdout
+            now = datetime.datetime.now().replace(tzinfo=TIMEZONE)
+            for ps_line in stdout:
+                process = ps_line_to_process(ps_line.decode("utf-8"), now)
+                processes[process.pid] = process
 
-        if ps.wait() != 0:
-            raise IOError("Exit code {} from {}".format(ps.returncode, command))
+            if ps.wait() != 0:
+                raise OSError(f"Exit code {ps.returncode} from {command}")
 
     resolve_links(processes, now)
     remove_process_and_descendants(processes, os.getpid())
@@ -478,22 +472,19 @@ def get_all():
     return list(processes.values())
 
 
-def order_best_last(processes):
-    # type: (Iterable[PxProcess]) -> List[PxProcess]
+def order_best_last(processes: Iterable[PxProcess]) -> List[PxProcess]:
     """Returns process list ordered with the most interesting one last"""
     return sorted(processes, key=operator.attrgetter("score", "cmdline"))
 
 
-def order_best_first(processes):
-    # type: (Iterable[PxProcess]) -> List[PxProcess]
+def order_best_first(processes: Iterable[PxProcess]) -> List[PxProcess]:
     """Returns process list ordered with the most interesting one first"""
     ordered = sorted(processes, key=operator.attrgetter("cmdline"))
     ordered = sorted(ordered, key=operator.attrgetter("score"), reverse=True)
     return ordered
 
 
-def seconds_to_str(seconds):
-    # type: (float) -> Text
+def seconds_to_str(seconds: float) -> str:
     if seconds < 60:
         seconds_s = str(seconds)
         decimal_index = seconds_s.rfind(".")
@@ -505,13 +496,13 @@ def seconds_to_str(seconds):
     if seconds < 3600:
         minutes = int(seconds / 60)
         remaining_seconds = int(seconds - minutes * 60)
-        return "{}m{:02d}s".format(minutes, remaining_seconds)
+        return f"{minutes}m{remaining_seconds:02d}s"
 
     if seconds < 86400:
         hours = int(seconds / 3600)
         minutes = int((seconds - 3600 * hours) / 60)
-        return "{}h{:02d}m".format(hours, minutes)
+        return f"{hours}h{minutes:02d}m"
 
     days = int(seconds / 86400)
     hours = int((seconds - 86400 * days) / 3600)
-    return "{}d{:02d}h".format(days, hours)
+    return f"{days}d{hours:02d}h"
