@@ -1,3 +1,4 @@
+import getpass
 import os
 import sys
 import errno
@@ -6,15 +7,12 @@ import select
 import termios
 import tty
 
-if sys.version_info.major >= 3:
-    # For mypy PEP-484 static typing validation
-    from six import text_type  # NOQA
-    from typing import Dict  # NOQA
-    from typing import List  # NOQA
-    from typing import Tuple  # NOQA
-    from typing import Optional  # NOQA
-    from typing import Iterable  # NOQA
-    from . import px_process  # NOQA
+from typing import Dict
+from typing import List
+from typing import Tuple
+from typing import Optional
+from typing import Iterable
+from . import px_process
 
 
 # NOTE: To work with this list it can be useful to find the text "Uncomment to
@@ -32,8 +30,8 @@ initial_termios_attr = None
 
 CSI = "\x1b["
 
-CURSOR_TO_TOP_LEFT = CSI + u"H"
-CURSOR_TO_RIGHT_EDGE = CSI + u"999C"  # Actually "999 steps to the right"
+CURSOR_TO_TOP_LEFT = CSI + "H"
+CURSOR_TO_RIGHT_EDGE = CSI + "999C"  # Actually "999 steps to the right"
 
 """
 Clear the screen and move cursor to top left corner:
@@ -45,26 +43,26 @@ for example, the contents of the previous screen gets added to the
 scrollback buffer, which isn't what we want. Tread carefully if you
 intend to change these.
 """
-CLEAR_SCREEN = CSI + u"1J" + CURSOR_TO_TOP_LEFT
+CLEAR_SCREEN = CSI + "1J" + CURSOR_TO_TOP_LEFT
 
-HIDE_CURSOR = CSI + u"?25l"
-SHOW_CURSOR = CSI + u"?25h"
+HIDE_CURSOR = CSI + "?25l"
+SHOW_CURSOR = CSI + "?25h"
 
-CLEAR_TO_EOL = CSI + u"0K"
+CLEAR_TO_EOL = CSI + "0K"
 CLEAR_TO_END_OF_SCREEN = CSI + "J"  # Clear from cursor to end of screen
 
-# Used for informing our getch() function that a window resize has occured
+# Used for informing our getch() function that a window resize has occurred
 SIGWINCH_PIPE = os.pipe()
 
 # We'll report window resize as this key having been pressed.
 #
 # NOTE: This must be detected as non-printable by handle_search_keypress().
-SIGWINCH_KEY = u"\x00"
+SIGWINCH_KEY = "\x00"
 
 _enable_color = True
 
-previous_screen_lines = []  # type: List[text_type]
-previous_screen_columns = 0  # type: int
+previous_screen_lines: List[str] = []
+previous_screen_columns: int = 0
 
 
 def disable_color():
@@ -72,7 +70,7 @@ def disable_color():
     _enable_color = False
 
 
-def sigwinch_handler(signum, frame):
+def sigwinch_handler(_signum, _frame):
     """Handle window resize signals by telling our getch() function to return"""
     # "r" for "refresh" perhaps? The actual letter doesn't matter, as long as it
     # doesn't collide with anything with some meaning other than "please
@@ -84,16 +82,14 @@ def sigwinch_handler(signum, frame):
 signal.signal(signal.SIGWINCH, sigwinch_handler)
 
 
-class ConsumableString(object):
-    def __init__(self, string):
-        # type: (text_type) -> None
+class ConsumableString:
+    def __init__(self, string: str) -> None:
         self._string = string
 
     def __len__(self):
         return len(self._string)
 
-    def consume(self, to_consume):
-        # type: (text_type) -> bool
+    def consume(self, to_consume: str) -> bool:
         if not self._string.startswith(to_consume):
             return False
 
@@ -102,19 +98,17 @@ class ConsumableString(object):
 
 
 def read_select(
-    fds,  # type: List[int]
-    timeout_seconds=None,  # type: Optional[int]
-):
-    # type: (...) -> List[int]
+    fds: List[int],
+    timeout_seconds: Optional[int] = None,
+) -> List[int]:
     """Select on any of the fds becoming ready for read, retry on EINTR"""
 
     # NOTE: If you change this method, you must test running "px --top" and
-    # resize the window in both Python 2 and Python 3.
+    # resize the window
     while True:
         try:
             return select.select(fds, [], [], timeout_seconds)[0]
         except OSError as ose:
-            # Python 3
             if ose.errno == errno.EINTR:
                 # EINTR happens when the terminal window is resized by the user,
                 # just try again.
@@ -122,19 +116,11 @@ def read_select(
 
             # Non-EINTR exceptions are unexpected, help!
             raise
-        except select.error as se:
-            # Python 2
-            if se.args[0] == errno.EINTR:
-                # EINTR happens when the terminal window is resized by the user,
-                # just try again.
-                continue
-
-            # Non-EINTR exceptions are unexpected, help!
-            raise
 
 
-def getch(timeout_seconds=None, fd=None):
-    # type: (Optional[int], int) -> Optional[ConsumableString]
+def getch(
+    timeout_seconds: Optional[int] = None, fd: int = None
+) -> Optional[ConsumableString]:
     """
     Wait at most timeout_seconds for a character to become available on stdin.
 
@@ -161,12 +147,10 @@ def getch(timeout_seconds=None, fd=None):
 
 
 class TerminalError(Exception):
-    def __init__(self, message):
-        super(TerminalError, self).__init__(message)
+    pass
 
 
-def get_window_size():
-    # type: () -> Tuple[int, int]
+def get_window_size() -> Tuple[int, int]:
     """
     Return the terminal window size as tuple (rows, columns).
 
@@ -198,10 +182,9 @@ def get_window_size():
     return (rows, columns)
 
 
-def raw_lines_to_screen_lines(raw_lines, columns):
-    # type: (List[text_type], int) -> List[text_type]
+def raw_lines_to_screen_lines(raw_lines: List[str], columns: int) -> List[str]:
     """Crop the lines to the right length and add clear-to-EOL at the end"""
-    screen_lines = []  # type: List[text_type]
+    screen_lines: List[str] = []
 
     for raw_line in raw_lines:
         cooked = crop_ansi_string_at_length(raw_line, columns)
@@ -211,11 +194,10 @@ def raw_lines_to_screen_lines(raw_lines, columns):
     return screen_lines
 
 
-def filter_out_unchanged_screen_lines(all_screen_lines, columns):
-    # type: (List[text_type], int) -> List[Optional[text_type]]
+def filter_out_unchanged_screen_lines(
+    all_screen_lines: List[str], columns: int
+) -> List[Optional[str]]:
     """Compare lines to the cache and None out the ones that match the cache"""
-    global previous_screen_lines
-    global previous_screen_columns
 
     if len(previous_screen_lines) != len(all_screen_lines):
         # Screen resized, never mind the cache
@@ -224,7 +206,7 @@ def filter_out_unchanged_screen_lines(all_screen_lines, columns):
         # Screen resized, never mind the cache
         return all_screen_lines  # type: ignore
 
-    filtered = []  # type: List[Optional[text_type]]
+    filtered: List[Optional[str]] = []
     for line_index, line in enumerate(all_screen_lines):
         line_from_previous_screen = previous_screen_lines[line_index]
         if line == line_from_previous_screen:
@@ -236,8 +218,7 @@ def filter_out_unchanged_screen_lines(all_screen_lines, columns):
     return filtered
 
 
-def draw_screen_lines(lines, columns):
-    # type: (List[text_type], int) -> None
+def draw_screen_lines(lines: List[str], columns: int) -> None:
 
     unfiltered_screen_lines = raw_lines_to_screen_lines(lines, columns)
     screen_lines = filter_out_unchanged_screen_lines(unfiltered_screen_lines, columns)
@@ -280,26 +261,63 @@ def draw_screen_lines(lines, columns):
     os.write(sys.stdout.fileno(), screenstring.encode("utf-8"))
 
 
-def width_specifier(width, right_align=False):
-    # type: (int, bool) -> text_type
-    return_me = u"{:"
+def width_specifier(width: int, right_align: bool = False) -> str:
+    return_me = "{:"
 
     if right_align:
-        return_me += u">"
+        return_me += ">"
 
     return_me += str(width)
-    return_me += u"}"
+    return_me += "}"
 
     return return_me
 
 
+def format_with_widths(widths: List[int], strings: List[str]) -> str:
+    """
+    Put strings next to each other with a space between each.
+
+    Negative column widths means right aligned text.
+
+    Zero width columns are unlimited.
+    """
+
+    assert len(widths) == len(strings)
+
+    result = ""
+    for i, width in enumerate(widths):
+        if i > 0:
+            result += " "
+
+        string = strings[i]
+
+        if width == 0:
+            result += string
+            continue
+
+        padding_amount = abs(width) - visual_length(string)
+        if padding_amount <= 0:
+            # NOTE: Future improvement: Crop here rather than just pretending
+            # everything is fine
+            result += string
+            continue
+
+        padding = padding_amount * " "
+        if width > 0:
+            result += string + padding
+        else:
+            # Right align
+            result += padding + string
+
+    return result
+
+
 def to_screen_lines(
-    procs,  # type: List[px_process.PxProcess]
-    row_to_highlight,  # type: Optional[int]
-    highlight_heading,  # type: Optional[text_type]
-    with_username=True,  # type: bool
-):
-    # type: (...) -> List[text_type]
+    procs: List[px_process.PxProcess],
+    row_to_highlight: Optional[int],
+    highlight_heading: Optional[str],
+    with_username: bool = True,
+) -> List[str]:
     """
     Returns an array of lines that can be printed to screen. Lines are not
     cropped, so they can be longer than the screen width.
@@ -309,15 +327,15 @@ def to_screen_lines(
     """
 
     headings = [
-        u"PID",
-        u"COMMAND",
-        u"USERNAME",
-        u"CPU",
-        u"CPUTIME",
-        u"RAM",
-        u"COMMANDLINE",
+        "PID",
+        "COMMAND",
+        "USERNAME",
+        "CPU",
+        "CPUTIME",
+        "RAM",
+        "COMMANDLINE",
     ]
-    highlight_column = None  # type: Optional[int]
+    highlight_column: Optional[int] = None
     if highlight_heading is not None:
         highlight_column = headings.index(highlight_heading)
 
@@ -336,22 +354,20 @@ def to_screen_lines(
         cputime_width = max(cputime_width, len(proc.cpu_time_s))
         mem_width = max(mem_width, len(proc.memory_percent_s))
 
-    format_specifiers = [
-        width_specifier(pid_width, right_align=True),
-        width_specifier(command_width),
-        width_specifier(username_width),
-        width_specifier(cpu_width, right_align=True),
-        width_specifier(cputime_width, right_align=True),
-        width_specifier(mem_width, right_align=True),
-        "{}",  # The command line can have any length
+    column_widths = [
+        -pid_width,
+        command_width,
+        username_width,
+        -cpu_width,
+        -cputime_width,
+        -mem_width,
+        0,  # The command line can have any length
     ]
 
     if not with_username:
         username_index = headings.index("USERNAME")
         del headings[username_index]
-        del format_specifiers[username_index]
-
-    format = " ".join(format_specifiers)
+        del column_widths[username_index]
 
     # Print process list using the computed column widths
     lines = []
@@ -360,16 +376,15 @@ def to_screen_lines(
     if highlight_column is not None:
         headings[highlight_column] = underline(headings[highlight_column])
 
-    heading_line = format.format(*headings)
+    heading_line = format_with_widths(column_widths, headings)
     heading_line = bold(heading_line)
     lines.append(heading_line)
 
-    max_cpu_percent_s = None  # type: Optional[text_type]
+    max_cpu_percent_s: Optional[str] = None
     max_cpu_percent = 0.0
-    max_memory_percent_s = None  # type: Optional[text_type]
+    max_memory_percent_s: Optional[str] = None
     max_memory_percent = 0.0
-    max_cpu_time_s = None  # type: Optional[text_type]
-    max_cpu_time = 0.0
+    max_cpu_time_seconds = 0.0
     for proc in procs:
         if proc.cpu_percent is not None and proc.cpu_percent > max_cpu_percent:
             max_cpu_percent = proc.cpu_percent
@@ -377,10 +392,13 @@ def to_screen_lines(
         if proc.memory_percent is not None and proc.memory_percent > max_memory_percent:
             max_memory_percent = proc.memory_percent
             max_memory_percent_s = proc.memory_percent_s
-        if proc.cpu_time_seconds is not None and proc.cpu_time_seconds > max_cpu_time:
-            max_cpu_time = proc.cpu_time_seconds
-            max_cpu_time_s = proc.cpu_time_s
+        if (
+            proc.cpu_time_seconds is not None
+            and proc.cpu_time_seconds > max_cpu_time_seconds
+        ):
+            max_cpu_time_seconds = proc.cpu_time_seconds
 
+    current_user = os.environ.get("SUDO_USER") or getpass.getuser()
     for line_number, proc in enumerate(procs):
         cpu_percent_s = proc.cpu_percent_s
         if proc.cpu_percent_s == "0%":
@@ -395,13 +413,27 @@ def to_screen_lines(
             memory_percent_s = bold(memory_percent_s.rjust(mem_width))
 
         cpu_time_s = proc.cpu_time_s
-        if proc.cpu_time_s == max_cpu_time_s:
+        if not proc.cpu_time_seconds:
+            # Zero or undefined
+            cpu_time_s = faint(cpu_time_s.rjust(cputime_width))
+        elif proc.cpu_time_seconds > 0.75 * max_cpu_time_seconds:
             cpu_time_s = bold(cpu_time_s.rjust(cputime_width))
+        elif proc.cpu_time_seconds < 0.1 * max_cpu_time_seconds:
+            cpu_time_s = faint(cpu_time_s.rjust(cputime_width))
+
+        # NOTE: This logic should match its friend in
+        # px_processinfo.py/print_process_tree()
+        owner = proc.username
+        if owner == "root":
+            owner = faint(owner)
+        elif owner != current_user:
+            # Neither root nor ourselves, highlight!
+            owner = bold(owner)
 
         columns = [
             str(proc.pid),
             proc.command,
-            proc.username,
+            owner,
             cpu_percent_s,
             cpu_time_s,
             memory_percent_s,
@@ -409,11 +441,11 @@ def to_screen_lines(
         ]
         if not with_username:
             del columns[username_index]
-        line = format.format(*columns)
+        line = format_with_widths(column_widths, columns)
 
         if row_to_highlight == line_number:
             # Highlight the whole screen line
-            line = inverse_video(line + u" " * 999)
+            line = inverse_video(line + " " * 999)
         lines.append(line)
 
     lines[0] = heading_line
@@ -421,64 +453,55 @@ def to_screen_lines(
     return lines
 
 
-def inverse_video(string):
-    # type: (text_type) -> text_type
-    global _enable_color
+def inverse_video(string: str) -> str:
     if not _enable_color:
         return string
     return CSI + "7m" + string + CSI + "27m"
 
 
-def bold(string):
-    # type: (text_type) -> text_type
-    global _enable_color
+def bold(string: str) -> str:
     if not _enable_color:
         return string
     return CSI + "1m" + string + CSI + "22m"
 
 
-def faint(string):
-    # type: (text_type) -> text_type
-    global _enable_color
+def faint(string: str) -> str:
     if not _enable_color:
         return string
     return CSI + "2m" + string + CSI + "22m"
 
 
-def underline(string):
-    # type: (text_type) -> text_type
-    global _enable_color
+def underline(string: str) -> str:
     if not _enable_color:
         return string
     return CSI + "4m" + string + CSI + "24m"
 
 
-def red(string):
-    # type: (text_type) -> text_type
-    global _enable_color
+def red(string: str) -> str:
     if not _enable_color:
         return string
-    return CSI + "1;30;41m" + string + CSI + "49;39;22m"
+    return CSI + "1;97;41m" + string + CSI + "49;39;22m"
 
 
-def yellow(string):
-    # type: (text_type) -> text_type
-    global _enable_color
+def yellow(string: str) -> str:
     if not _enable_color:
         return string
     return CSI + "30;103m" + string + CSI + "49;39m"
 
 
-def green(string):
-    # type: (text_type) -> text_type
-    global _enable_color
+def green(string: str) -> str:
     if not _enable_color:
         return string
     return CSI + "1;32m" + string + CSI + "39;22m"
 
 
-def get_string_of_length(string, length):
-    # type: (text_type, Optional[int]) -> text_type
+def blue(string: str) -> str:
+    if not _enable_color:
+        return string
+    return CSI + "1;97;44m" + string + CSI + "49;39;22m"
+
+
+def get_string_of_length(string: str, length: Optional[int]) -> str:
     if length is None:
         return string
 
@@ -487,7 +510,7 @@ def get_string_of_length(string, length):
         return string
 
     if initial_length < length:
-        return string + u" " * (length - initial_length)
+        return string + " " * (length - initial_length)
 
     if initial_length > length:
         return crop_ansi_string_at_length(string, length)
@@ -495,8 +518,7 @@ def get_string_of_length(string, length):
     assert False  # How did we end up here?
 
 
-def _tokenize(string):
-    # type: (text_type) -> Iterable[text_type]
+def _tokenize(string: str) -> Iterable[str]:
     """
     Tokenizes string into character sequences and ANSI sequences.
     """
@@ -530,14 +552,12 @@ def _tokenize(string):
     yield string[i:]
 
 
-crop_cache = {}  # type: Dict[Tuple[text_type, int], text_type]
+crop_cache: Dict[Tuple[str, int], str] = {}
 
 
-def crop_ansi_string_at_length(string, length):
-    # type: (text_type, int) -> text_type
+def crop_ansi_string_at_length(string: str, length: int) -> str:
     assert length >= 0
 
-    global crop_cache
     cache_key = (string, length)
     cache_hit = crop_cache.get(cache_key, None)
     if cache_hit is not None:
@@ -546,10 +566,10 @@ def crop_ansi_string_at_length(string, length):
         # LRU would be better but this is easier to implement
         crop_cache.clear()
 
-    result = u""
+    result = ""
     char_count = 0
 
-    reset_sequence = u""
+    reset_sequence = ""
 
     for token in _tokenize(string):
         if token.startswith(CSI):
@@ -574,8 +594,7 @@ def crop_ansi_string_at_length(string, length):
     return cache_hit
 
 
-def visual_length(string):
-    # type: (text_type) -> int
+def visual_length(string: str) -> int:
     """
     If we print this string, possibly containing ANSI characters, to
     screen, how many characters wide will it be?
@@ -622,7 +641,6 @@ def _exit_fullscreen():
 class fullscreen_display:
     def __enter__(self):
         _enter_fullscreen()
-        return None
 
     def __exit__(self, exception_type, exception_value, exception_traceback):
         _exit_fullscreen()
@@ -639,7 +657,6 @@ class normal_display:
 
     def __enter__(self):
         _exit_fullscreen()
-        return None
 
     def __exit__(self, exception_type, exception_value, exception_traceback):
         _enter_fullscreen()
