@@ -1,8 +1,5 @@
-# coding=utf-8
-
 import sys
 import copy
-import time
 import logging
 import unicodedata
 
@@ -12,14 +9,11 @@ from . import px_terminal
 from . import px_processinfo
 from . import px_process_menu
 from . import px_poller
+from . import px_category_bar
 
-if sys.version_info.major >= 3:
-    # For mypy PEP-484 static typing validation
-    from typing import List  # NOQA
-    from typing import Dict  # NOQA
-    from typing import Union  # NOQA
-    from typing import Optional  # NOQA
-    from six import text_type  # NOQA
+from typing import List
+from typing import Dict
+from typing import Optional
 
 LOG = logging.getLogger(__name__)
 
@@ -36,30 +30,31 @@ SEARCH_CURSOR = px_terminal.inverse_video(" ")
 MODE_BASE = 0
 MODE_SEARCH = 1
 
-top_mode = MODE_BASE  # type: int
-search_string = u""
+top_mode: int = MODE_BASE
+search_string = ""
 
 # Which pid were we last hovering?
-last_highlighted_pid = None  # type: Optional[int]
+last_highlighted_pid: Optional[int] = None
 
 # Which row were we last hovering? Go for this one if
 # we can't use last_pid.
-last_highlighted_row = 0  # type: int
+last_highlighted_row: int = 0
 
 # Has the user manually moved the highlight? If not, just stay on the top
 # row even if the tow PID moves away.
-highlight_has_moved = False  # type: bool
+highlight_has_moved: bool = False
 
 # Order top list by memory usage. The opposite is by CPU usage.
 sort_by_memory = False
 
 
-def adjust_cpu_times(baseline, current):
-    # type: (List[px_process.PxProcess], List[px_process.PxProcess]) -> List[px_process.PxProcess]
+def adjust_cpu_times(
+    baseline: List[px_process.PxProcess], current: List[px_process.PxProcess]
+) -> List[px_process.PxProcess]:
     """
     Identify processes in current that are also in baseline.
 
-    For all matches, substract the baseline process' CPU time usage from the
+    For all matches, subtract the baseline process' CPU time usage from the
     current process' one.
 
     This way we get CPU times computed from when "px --top" was started, rather
@@ -67,7 +62,7 @@ def adjust_cpu_times(baseline, current):
 
     Neither current nor baseline are changed by this function.
     """
-    pid2proc = {}  # type: Dict[int,px_process.PxProcess]
+    pid2proc: Dict[int, px_process.PxProcess] = {}
     for proc in current:
         pid2proc[proc.pid] = proc
 
@@ -82,11 +77,11 @@ def adjust_cpu_times(baseline, current):
             continue
 
         if current_proc.cpu_time_seconds is None:
-            # We can't substract from None
+            # We can't subtract from None
             continue
 
         if baseline_proc.cpu_time_seconds is None:
-            # We can't substract None
+            # We can't subtract None
             continue
 
         current_proc = copy.copy(current_proc)
@@ -99,16 +94,14 @@ def adjust_cpu_times(baseline, current):
     return list(pid2proc.values())
 
 
-def get_notnone_cpu_time_seconds(proc):
-    # type: (px_process.PxProcess) -> float
+def get_notnone_cpu_time_seconds(proc: px_process.PxProcess) -> float:
     seconds = proc.cpu_time_seconds
     if seconds is not None:
         return seconds
     return 0
 
 
-def get_notnone_memory_percent(proc):
-    # type: (px_process.PxProcess) -> float
+def get_notnone_memory_percent(proc: px_process.PxProcess) -> float:
     percent = proc.memory_percent
     if percent is not None:
         return percent
@@ -135,9 +128,9 @@ def sort_by_cpu_usage(toplist):
 
 
 def get_toplist(
-    baseline,  # type: List[px_process.PxProcess]
-    current,  # type: List[px_process.PxProcess]
-    by_memory=False,  # type: bool
+    baseline: List[px_process.PxProcess],
+    current: List[px_process.PxProcess],
+    by_memory: bool = False,
 ):
     # type(...) -> List[px_process.PxProcess]
     toplist = adjust_cpu_times(baseline, current)
@@ -153,13 +146,13 @@ def get_toplist(
     return toplist
 
 
-def writebytes(bytestring):
-    # type: (bytes) -> None
+def writebytes(bytestring: bytes) -> None:
     os.write(sys.stdout.fileno(), bytestring)
 
 
-def get_line_to_highlight(toplist, max_process_count):
-    # type: (List[px_process.PxProcess], int) -> Optional[int]
+def get_line_to_highlight(
+    toplist: List[px_process.PxProcess], max_process_count: int
+) -> Optional[int]:
     global last_highlighted_pid
     global last_highlighted_row
     global highlight_has_moved
@@ -202,15 +195,94 @@ def get_line_to_highlight(toplist, max_process_count):
     return last_highlighted_row
 
 
-def get_screen_lines(
-    toplist,  # type: List[px_process.PxProcess]
-    poller,  # type: px_poller.PxPoller
-    rows,  # type: int
-    include_footer=True,  # type: bool
-    search=None,  # type: Optional[text_type]
-):
-    # type: (...) -> List[text_type]
+def generate_header(
+    filtered_processes: List[px_process.PxProcess],
+    poller: px_poller.PxPoller,
+    screen_columns: int,
+) -> List[str]:
+    assert screen_columns > 0
 
+    sysload_line = px_terminal.bold("Sysload: ") + poller.get_loadstring()
+    ramuse_line = px_terminal.bold("RAM Use: ") + poller.get_meminfo()
+
+    if px_terminal.visual_length(sysload_line) > (screen_columns // 2 - 1):
+        # Traditional header
+        bar_length = screen_columns - 16
+        if bar_length > 20:
+            # Enough space for usable category bars. Length limit ^ picked entirely
+            # arbitrarily, feel free to change it if you have a better number.
+            rambar_by_program = (
+                "["
+                + px_category_bar.ram_by_program(bar_length, filtered_processes)
+                + "]"
+            )
+            rambar_by_user = (
+                "[" + px_category_bar.ram_by_user(bar_length, filtered_processes) + "]"
+            )
+        else:
+            rambar_by_program = "[ ... ]"
+            rambar_by_user = "[ ... ]"
+
+        # Print header
+        return [
+            sysload_line,
+            ramuse_line,
+            "  By program: " + rambar_by_program,
+            "     By user: " + rambar_by_user,
+            px_terminal.bold("IO Load:      ") + poller.get_ioload_string(),
+            "",
+        ]
+
+    # Make a split header
+    bar_length = screen_columns // 2 - 3
+    if bar_length > 20:
+        # Enough space for usable category bars. Length limit ^ picked entirely
+        # arbitrarily, feel free to change it if you have a better number.
+        cpubar_by_program = (
+            "[" + px_category_bar.cpu_by_program(bar_length, filtered_processes) + "]"
+        )
+        cpubar_by_user = (
+            "[" + px_category_bar.cpu_by_user(bar_length, filtered_processes) + "]"
+        )
+        rambar_by_program = (
+            "[" + px_category_bar.ram_by_program(bar_length, filtered_processes) + "]"
+        )
+        rambar_by_user = (
+            "[" + px_category_bar.ram_by_user(bar_length, filtered_processes) + "]"
+        )
+    else:
+        cpubar_by_program = "[ ... ]"
+        cpubar_by_user = "[ ... ]"
+        rambar_by_program = "[ ... ]"
+        rambar_by_user = "[ ... ]"
+
+    return [
+        px_terminal.get_string_of_length(sysload_line, screen_columns // 2)
+        + ramuse_line,
+        px_terminal.get_string_of_length(cpubar_by_program, screen_columns // 2)
+        + rambar_by_program,
+        px_terminal.get_string_of_length(cpubar_by_user, screen_columns // 2)
+        + rambar_by_user,
+        px_terminal.bold("IO Load:      ") + poller.get_ioload_string(),
+        "",
+    ]
+
+
+def get_screen_lines(
+    toplist: List[px_process.PxProcess],
+    poller: px_poller.PxPoller,
+    screen_rows: int,
+    screen_columns: int,
+    include_footer: bool = True,
+    search: Optional[str] = None,
+) -> List[str]:
+    """
+    Note that the columns parameter is only used for layout purposes. Lines
+    returned from this function will still need to be cropped before being
+    printed to screen.
+    """
+
+    all_processes = toplist
     if search:
         # Note that we accept partial user name match, otherwise incrementally typing
         # a username becomes weird for the ptop user
@@ -224,18 +296,20 @@ def get_screen_lines(
     if include_footer:
         footer_height = 1
 
-    # Print header
-    lines = [
-        px_terminal.bold(u"Sysload: ") + poller.get_loadstring(),
-        px_terminal.bold(u"RAM Use: ") + poller.get_meminfo(),
-        px_terminal.bold(u"IO Load:      ") + poller.get_ioload_string(),
-        u"",
-    ]
+    lines = generate_header(all_processes, poller, screen_columns)
 
-    # Create a launchers section
+    # Create a launches section
     header_height = len(lines)
-    launches_maxheight = rows - header_height - cputop_minheight - footer_height
-    launchlines = []  # type: List[text_type]
+    main_area_height = screen_rows - header_height - footer_height
+    launches_maxheight1 = (
+        main_area_height - cputop_minheight
+    )  # Give CPU top part enough space
+    launches_maxheight2 = (
+        main_area_height * 30
+    ) // 100  # https://github.com/walles/px/issues/98
+    launches_maxheight = min(launches_maxheight1, launches_maxheight2)
+
+    launchlines: List[str] = []
     if launches_maxheight >= 3:
         launchlines = poller.get_launchcounter_lines()
         if len(launchlines) > 0:
@@ -249,7 +323,7 @@ def get_screen_lines(
             launchlines = launchlines[0:launches_maxheight]
 
     # Compute cputop height now that we know how many launchlines we have
-    cputop_height = rows - header_height - len(launchlines) - footer_height
+    cputop_height = screen_rows - header_height - len(launchlines) - footer_height
 
     # -2 = Section name + column headings
     max_process_count = cputop_height - 2
@@ -258,20 +332,19 @@ def get_screen_lines(
     max_process_count -= 1
 
     highlight_row = get_line_to_highlight(toplist, max_process_count)
-    global top_mode
     if top_mode == MODE_SEARCH:
         highlight_row = None
 
-    highlight_column = u"CPUTIME"
+    highlight_column = "CPUTIME"
     if sort_by_memory:
-        highlight_column = u"RAM"
+        highlight_column = "RAM"
     toplist_table_lines = px_terminal.to_screen_lines(
         toplist[:max_process_count], highlight_row, highlight_column
     )
 
     # Ensure that we cover the whole screen, even if it's higher than the
     # number of processes
-    toplist_table_lines += rows * [""]
+    toplist_table_lines += screen_rows * [""]
 
     top_what = "CPU"
     if sort_by_memory:
@@ -284,18 +357,19 @@ def get_screen_lines(
         assert top_mode == MODE_BASE
         lines += [SEARCH_PROMPT_INACTIVE + px_terminal.bold(search or "")]
 
-    lines += toplist_table_lines[
-        0 : max_process_count + 1
-    ]  # +1 for the column headings
+    if max_process_count > 0:
+        lines += toplist_table_lines[
+            0 : max_process_count + 1
+        ]  # +1 for the column headings
 
     lines += launchlines
 
     if include_footer:
         footer_line = (
-            u"  q - Quit  m - Sort order  / - Search  ↑↓ - Move  Enter - Select"
+            "  q - Quit  m - Sort order  / - Search  ↑↓ - Move  Enter - Select"
         )
         # Inverse the whole footer line
-        footer_line = px_terminal.inverse_video(footer_line + 999 * u" ")
+        footer_line = px_terminal.inverse_video(footer_line + 999 * " ")
 
         lines += [footer_line]
 
@@ -303,28 +377,25 @@ def get_screen_lines(
 
 
 def redraw(
-    toplist,  # type: List[px_process.PxProcess]
-    poller,  # type: px_poller.PxPoller
-    rows,  # type: int
-    columns,  # type: int
-    include_footer=True,  # type: bool
-):
-    # type: (...) -> None
+    toplist: List[px_process.PxProcess],
+    poller: px_poller.PxPoller,
+    rows: int,
+    columns: int,
+    include_footer: bool = True,
+) -> None:
     """
     Refresh display.
 
     The new display will be rows rows x columns columns.
     """
-    global search_string
     lines = get_screen_lines(
-        toplist, poller, rows, include_footer, search=search_string
+        toplist, poller, rows, columns, include_footer, search=search_string
     )
 
     px_terminal.draw_screen_lines(lines, columns)
 
 
-def handle_search_keypresses(key_sequence):
-    # type: (px_terminal.ConsumableString) -> None
+def handle_search_keypresses(key_sequence: px_terminal.ConsumableString) -> None:
     global search_string
     global last_highlighted_row
     global last_highlighted_pid
@@ -383,27 +454,27 @@ def get_command(**kwargs):
     """
     Call getch() and interpret the results.
     """
-    input = px_terminal.getch(**kwargs)
-    if input is None:
+    user_input = px_terminal.getch(**kwargs)
+    if user_input is None:
         return None
-    assert len(input) > 0
+    assert len(user_input) > 0
 
     global top_mode
     if top_mode == MODE_SEARCH:
-        handle_search_keypresses(input)
+        handle_search_keypresses(user_input)
         return CMD_HANDLED
 
     global last_highlighted_row
     global last_highlighted_pid
     global sort_by_memory
-    while len(input) > 0:
-        if input.consume(px_terminal.KEY_UPARROW):
+    while len(user_input) > 0:
+        if user_input.consume(px_terminal.KEY_UPARROW):
             last_highlighted_row -= 1
             last_highlighted_pid = None
-        elif input.consume(px_terminal.KEY_DOWNARROW):
+        elif user_input.consume(px_terminal.KEY_DOWNARROW):
             last_highlighted_row += 1
             last_highlighted_pid = None
-        elif input.consume(px_terminal.KEY_ENTER):
+        elif user_input.consume(px_terminal.KEY_ENTER):
             if last_highlighted_pid is None:
                 continue
             processes = px_process.get_all()
@@ -413,17 +484,16 @@ def get_command(**kwargs):
             if not process:
                 continue
             px_process_menu.PxProcessMenu(process).start()
-        elif input.consume(u"/"):
-            global search_string
+        elif user_input.consume("/"):
             top_mode = MODE_SEARCH
             return None
-        elif input.consume(u"m") or input.consume(u"M"):
+        elif user_input.consume("m") or user_input.consume("M"):
             sort_by_memory = not sort_by_memory
-        elif input.consume(u"q"):
+        elif user_input.consume("q"):
             return CMD_QUIT
-        elif input.consume(px_terminal.SIGWINCH_KEY):
+        elif user_input.consume(px_terminal.SIGWINCH_KEY):
             return CMD_RESIZE
-        elif input.consume(px_poller.POLL_COMPLETE_KEY):
+        elif user_input.consume(px_poller.POLL_COMPLETE_KEY):
             return CMD_POLL_COMPLETE
         else:
             # Unable to consume anything, give up
@@ -432,8 +502,7 @@ def get_command(**kwargs):
     return CMD_WHATEVER
 
 
-def _top(search=""):
-    # type: (str) -> None
+def _top(search: str = "") -> None:
 
     global search_string
     search_string = search
@@ -444,7 +513,6 @@ def _top(search=""):
     baseline = poller.get_all_processes()
     current = poller.get_all_processes()
 
-    global sort_by_memory
     toplist = get_toplist(baseline, current, sort_by_memory)
 
     rows, columns = px_terminal.get_window_size()
@@ -472,19 +540,18 @@ def _top(search=""):
                 toplist = get_toplist(baseline, current, sort_by_memory)
 
 
-def top(search=""):
-    # type: (str) -> None
+def top(search: str = "") -> None:
 
     if not sys.stdout.isatty():
         sys.stderr.write(
             'Top mode only works on TTYs, try running just "px" instead.\n'
         )
-        exit(1)
+        sys.exit(1)
 
     with px_terminal.fullscreen_display():
         try:
             _top(search=search)
-        except Exception:
+        except Exception:  # pylint: disable=broad-except
             LOG.exception("Running ptop failed")
 
         # Make sure we actually end up on a new line
