@@ -1,5 +1,3 @@
-# coding=utf-8
-
 import os
 
 from px import px_commandline
@@ -68,7 +66,6 @@ def test_get_command_java():
 
     # FIXME: Add test for classpath containing spaces? I say this should be
     # postponed until we have a real world use case for that.
-    pass
 
 
 def test_get_command_java_gradled():
@@ -182,6 +179,24 @@ def test_get_command_java_equinox():
     )
 
 
+def test_get_command_electron_macos():
+    # Note that if we have spaces inside of the path, the path in
+    # question needs to be valid on the local system for it to
+    # be deciphered properly by px. So this path is from an actual
+    # path, but with all spaces removed.
+    assert (
+        px_commandline.get_command(
+            "/Applications/VisualStudioCode.app/Contents/MacOS/Electron "
+            "--ms-enable-electron-run-as-node "
+            "/Users/johan/.vscode/extensions/ms-python.vscode-pylance-2021.12.2/dist/server.bundle.js "
+            "--cancellationReceive=file:d6fe53594ec46a8bb986ad058c985f56d309e7bf19 "
+            "--node-ipc "
+            "--clientProcessId=42516 "
+        )
+        == "VisualStudioCode"
+    )
+
+
 def test_get_command_resque():
     # These command names are from a real-world system
     assert px_commandline.get_command("resque-1.20.0: x y z") == "resque-1.20.0:"
@@ -253,7 +268,7 @@ def test_get_command_interpreters():
 
 
 def test_get_command_unicode():
-    assert px_commandline.get_command(u"😀") == u"😀"
+    assert px_commandline.get_command("😀") == "😀"
 
 
 def test_get_command_ruby_switches():
@@ -264,6 +279,20 @@ def test_get_command_ruby_switches():
         == "brew.rb"
     )
 
+    # https://github.com/walles/px/issues/87
+    assert (
+        px_commandline.get_command("/usr/bin/ruby -W1 -- /apa/build.rb /bepa/cmake.rb")
+        == "build.rb"
+    )
+
+    # https://github.com/walles/px/issues/74
+    assert (
+        px_commandline.get_command(
+            "/usr/bin/ruby -Eascii-8bit:ascii-8bit /usr/sbin/google-fluentd"
+        )
+        == "google-fluentd"
+    )
+
 
 def test_get_command_perl():
     # Source: https://github.com/walles/px/issues/85
