@@ -2,32 +2,29 @@ import getpass
 import datetime
 
 import os
-import six
 import pytest
 
 from px import px_process
 from . import testutils
 
-import sys
-
-if sys.version_info.major >= 3:
-    # For mypy PEP-484 static typing validation
-    from typing import MutableSet  # NOQA
+from typing import MutableSet
 
 
 def test_create_process():
     process_builder = px_process.PxProcessBuilder()
     process_builder.pid = 7
     process_builder.ppid = 1
+    process_builder.rss_kb = 123
     process_builder.start_time_string = testutils.TIMESTRING
     process_builder.username = "usernamex"
     process_builder.cpu_time = 1.3
     process_builder.memory_percent = 42.7
     process_builder.cmdline = "hej kontinent"
-    test_me = process_builder.build(testutils.now())
+    test_me = process_builder.build(testutils.local_now())
 
     assert test_me.pid == 7
     assert test_me.ppid == 1
+    assert test_me.rss_kb == 123
     assert test_me.username == "usernamex"
     assert test_me.cpu_time_s == "1.3s"
     assert test_me.memory_percent_s == "43%"
@@ -57,6 +54,7 @@ def test_create_future_process():
     # These values are required to not fail in other ways
     process_builder.cmdline = "hej kontinent"
     process_builder.pid = 1
+    process_builder.rss_kb = 123
     process_builder.username = "johan"
 
     # Test it!
@@ -67,8 +65,8 @@ def test_create_future_process():
 def test_ps_line_to_process_unicode():
     process = testutils.create_process(cputime="2:14.15")
 
-    assert process.username == u"root"
-    assert process.cmdline == u"/usr/sbin/cupsd -l"
+    assert process.username == "root"
+    assert process.cmdline == "/usr/sbin/cupsd -l"
 
 
 def test_ps_line_to_process_1():
@@ -104,6 +102,7 @@ def test_ps_line_to_process_3():
     process = px_process.ps_line_to_process(
         "  5328"
         "   4432"
+        "   123"
         " Thu Feb 25 07:42:36 2016"
         " " + str(os.getuid()) + " 5.5"
         "    1-19:31:31"
@@ -117,7 +116,7 @@ def test_ps_line_to_process_3():
         " --pid-file=/var/run/mysqld/mysqld.pid"
         " --socket=/var/run/mysqld/mysqld.sock"
         " --port=3306",
-        testutils.now(),
+        testutils.local_now(),
     )
     assert process.username == getpass.getuser()
     assert process.cpu_percent_s == "6%"
@@ -134,7 +133,7 @@ def _validate_references(processes):
         else:
             assert process.parent is not None
 
-        assert type(process.children) is set
+        assert isinstance(process.children, set)
         if process.parent:
             assert process.parent in processes
             assert process.parent.pid == process.ppid
@@ -146,12 +145,12 @@ def _validate_references(processes):
 
 
 def _test_get_all():
-    all = px_process.get_all()
-    assert len(all) >= 4  # Expect at least kernel, init, bash and python
-    for process in all:
+    all_processes = px_process.get_all()
+    assert len(all_processes) >= 4  # Expect at least kernel, init, bash and python
+    for process in all_processes:
         assert process is not None
 
-    pids = list(map(lambda p: p.pid, all))
+    pids = list(map(lambda p: p.pid, all_processes))
 
     # Finding ourselves is just confusing...
     assert os.getpid() not in pids
@@ -166,22 +165,22 @@ def _test_get_all():
     assert 1 in pids
 
     # Assert that all contains no duplicate PIDs
-    seen_pids = set()  # type: MutableSet[int]
-    for process in all:
+    seen_pids: MutableSet[int] = set()
+    for process in all_processes:
         pid = process.pid
         assert pid not in seen_pids
         seen_pids.add(pid)
 
     # Assert that there are processes with the current user name
     current_users_processes = filter(
-        lambda process: process.username == getpass.getuser(), all
+        lambda process: process.username == getpass.getuser(), all_processes
     )
     assert current_users_processes
 
-    _validate_references(all)
+    _validate_references(all_processes)
 
-    now = testutils.now()
-    for process in all:
+    now = testutils.local_now()
+    for process in all_processes:
         # Scores should be computed via multiplications and divisions of
         # positive numbers, if this value is negative something is wrong.
         assert process.score >= 0
@@ -190,9 +189,9 @@ def _test_get_all():
         assert process.age_seconds >= 0
         assert process.start_time < now
 
-    for process in all:
-        assert isinstance(process.cmdline, six.text_type)
-        assert isinstance(process.username, six.text_type)
+    for process in all_processes:
+        assert isinstance(process.cmdline, str)
+        assert isinstance(process.username, str)
 
 
 def test_get_all_swedish():
@@ -218,7 +217,7 @@ def test_process_eq():
     process_a = testutils.create_process()
 
     process_b = testutils.create_process()
-    parent = px_process.create_kernel_process(testutils.now())
+    parent = px_process.create_kernel_process(testutils.local_now())
     process_b.parent = parent
 
     assert process_a != process_b
@@ -364,11 +363,11 @@ def test_command_in_parentheses():
 def test_uid_to_username():
     username = px_process.uid_to_username(os.getuid())
     assert username == getpass.getuser()
-    assert isinstance(username, six.text_type)
+    assert isinstance(username, str)
 
     username = px_process.uid_to_username(456789)
     assert username == "456789"
-    assert isinstance(username, six.text_type)
+    assert isinstance(username, str)
 
 
 def test_resolve_links():
@@ -376,7 +375,7 @@ def test_resolve_links():
     p1 = testutils.create_process(pid=1, ppid=UNKNOWN_PID)
     p2 = testutils.create_process(pid=2, ppid=1)
     processes = {p1.pid: p1, p2.pid: p2}
-    px_process.resolve_links(processes, testutils.now())
+    px_process.resolve_links(processes, testutils.local_now())
 
     assert p1.parent is None
     assert p2.parent is p1
